@@ -309,8 +309,7 @@ class Experimento:
         self.distancia_a_objeto_promediado = \
             m_dist.obtener_arreglo_con_valores_promediados_para_distancia_a_objeto(arreglo_elegido, intervalo)
 
-    def calcula_velocidades(self):
-
+    def calcula_velocidad_aceleracion(self):
         self.serie_velocidad = m_vel.calcula_serie_velocidad(self.tiempo,
                                                              self.posiciones_x,
                                                              self.posiciones_y)
@@ -330,7 +329,7 @@ class Experimento:
                                            categoria="aceleracion",
                                            serie=self.serie_aceleracion)
 
-    def calcula_entropias_histogramas_vel_acel(self):
+    def agrega_entropias_histogramas_vel_acel(self):
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="histograma_velocidad",
                                        datos=self.histogramas["velocidad"])
@@ -418,6 +417,12 @@ class Experimento:
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="visitas_regiones",
                                        datos=self.matriz_cuadriculada.flatten())
+        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
+                                       categoria="visitas_regiones_preferidas",
+                                       datos=self.matriz_cuadriculada_regiones_preferidas.flatten())
+        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
+                                       categoria="visitas_regiones_no_preferidas",
+                                       datos=self.matriz_cuadriculada_solo_regiones_no_preferidas.flatten())
 
     def calcula_entropias_aproximadas_regiones_cuadriculadas(self,
                                                              tamanio_vectorial,
@@ -433,7 +438,6 @@ class Experimento:
                                                   umbral=umbral,
                                                   sobreposicion=sobreposicion)
 
-
     def calcula_matrices_de_recurrencia(self):
         self.matriz_recurrencia_region_cuadriculada = \
             m_recurr.calcula_matrices_de_recurrencia(self.arreglo_region_cuadriculada)
@@ -476,19 +480,11 @@ class Experimento:
         self.matriz_cuadriculada_solo_regiones_preferidas = \
             np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas)
 
-        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
-                                       categoria="visitas_regiones_preferidas",
-                                       datos=self.matriz_cuadriculada_solo_regiones_preferidas.flatten())
-
         self.matriz_cuadriculada_solo_regiones_no_preferidas = \
             m_reg_pref.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_no_preferidas)
         self.matriz_cuadriculada_solo_regiones_no_preferidas = \
             np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
 
-        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
-                                       categoria="visitas_regiones_no_preferidas",
-                                       datos=self.matriz_cuadriculada_solo_regiones_no_preferidas.flatten())
-
     def calcula_arreglos_rutas_vectoriales(self,
                                            tamanio_vectorial,
                                            brinco_temporal,
